Skip to contents

Function to visualise the average game price per year Genres include: Action, Adventure, Casual, Indie, MassivelyMultiplayer, Racing, RPG, Simulation, Sports, Strategy

Usage

avgpriceperyear(games, selectedgenres = NULL)

Arguments

games

The "games" dataset

selectedgenres

Vector of genres to be visualised, OPTIONAL (all genres are selected if this parameter is not provided)

Value

avgpriceplot a ggplot object

Examples

avgpriceperyear(games, selectedgenres = c("Action", "Indie", "Simulation"))