Skip to contents

This function generates an S3 object summarizing a game's details.

Usage

get_game_details(app_id)

Arguments

app_id

The Steam App ID of the game.

Value

An S3 object of class 'game_details'.

Examples

game <- get_game_details(72850)
print(game)
#> Game Details:
#> app_id: 72850
#> name: The Elder Scrolls V: Skyrim
#> description: EPIC FANTASY REBORN The next chapter in the highly anticipated Elder Scrolls saga arrives from the makers of the 2006 and 2008 Games of the Year, Bethesda Game Studios. Skyrim reimagines and revolutionizes the open-world fantasy epic, bringing to life a complete virtual world open for you to explore any way you choose.
#> image: https://shared.akamai.steamstatic.com/store_item_assets/steam/apps/72850/header.jpg?t=1721923139
#> developers: ['Bethesda Game Studios']
#> publishers: ['Bethesda Softworks']
#> price: 14.99
#> metacritic: 94
#> genres: ['RPG']
#> recommendations: 181044
#> release_date: 2011-11-10
summary(game)
#> Summary of Game Details:
#> Name: The Elder Scrolls V: Skyrim 
#> Release Year: 2011 
#> Genres: ['RPG'] 
#> Price: 14.99 EUR
#> Recommendations: 181044 
#> Metacritic: 94